@@ -40,7 +40,7 @@ test_that("createReport", {
   
   r = createReport(txt_folder, NULL, yaml_obj)
   expect_equal(c("yaml_file", "heatmap_values_file", "R_plots_file", "filename_sorting", "stats_file",         
-                 "log_file", "report_file_prefix", "report_file_PDF", "report_file_HTML"), names(r))
+                 "log_file", "qc_file", "report_file_prefix", "report_file_PDF", "report_file_HTML"), names(r))
   rep_files = c(r[["report_file_PDF"]], r[["report_file_HTML"]])
   
   print(list.files(path = txt_folder))
@@ -49,7 +49,7 @@ test_that("createReport", {
   {
     cat("Checking file ", f, "\n")
     # HTML file might not exist if PANDOC is not installed
-    if (file.exists(f)) expect_equal(file.info(f)$size > 100*1024, TRUE) ## ~119kb PDF & HTML
+    if (file.exists(f)) expect_equal(file.info(f)$size > 50*1024, TRUE) ## PDF 70kb & HTML 161kb
   }
   
   expect_equal(file.exists(r[["heatmap_values_file"]]), TRUE)
